<?php
namespace TYPO3\CMS\Fluid\Core;

/*                                                                        *
 * This script is backported from the TYPO3 Flow package "TYPO3.Fluid".   *
 *                                                                        *
 * It is free software; you can redistribute it and/or modify it under    *
 * the terms of the GNU Lesser General Public License, either version 3   *
 *  of the License, or (at your option) any later version.                *
 *                                                                        *
 * The TYPO3 project - inspiring people to share!                         *
 *                                                                        */
/**
 * A generic Fluid Core exception.
 *
 * @api
 */
class Exception extends \TYPO3\CMS\Fluid\Exception
{
}
